IMAP mailbox adapter implementing IImapMailbox.
Uses javax.mail for IMAP access. Connections are opened per-call and closed in a finally block. IMAP UIDs are accessed by casting the Folder to IMAPFolder.
Usage: (def mailbox (create-imap-mailbox {:host "imap.gmail.com" :port 993 :username "user@gmail.com" :password "app-password" :ssl? true})) (fetch-unread! mailbox)
IMAP mailbox adapter implementing IImapMailbox.
Uses javax.mail for IMAP access. Connections are opened per-call and closed
in a finally block. IMAP UIDs are accessed by casting the Folder to IMAPFolder.
Usage:
(def mailbox (create-imap-mailbox
{:host "imap.gmail.com"
:port 993
:username "user@gmail.com"
:password "app-password"
:ssl? true}))
(fetch-unread! mailbox)(create-imap-mailbox {:keys [host port username password ssl? folder]
:or {ssl? true folder "INBOX"}})Create an IMAP mailbox adapter.
Config keys: :host - IMAP server hostname (required) :port - IMAP server port (required) :username - IMAP auth username (required) :password - IMAP auth password (required) :ssl? - Enable SSL/TLS (default true) :folder - Default folder name (default "INBOX")
Returns: ImapMailboxAdapter implementing IImapMailbox
Create an IMAP mailbox adapter. Config keys: :host - IMAP server hostname (required) :port - IMAP server port (required) :username - IMAP auth username (required) :password - IMAP auth password (required) :ssl? - Enable SSL/TLS (default true) :folder - Default folder name (default "INBOX") Returns: ImapMailboxAdapter implementing IImapMailbox
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |